@@ -269,42 +269,42 @@ bool CompoundWidget::getOptions( bool& needRoot )
 	TQString targetFileValue  = m_targetFileLineEdit->text( );
 
 	if( dataDirState && dataDirValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Data directory name not specified" )), i18n( "Data directory name error" ));
+	{	KMessageBox::error( this, i18n( "Data directory name not specified" ), i18n( "Data directory name error" ));
 		return false;
 	}
 
 	if( decoyState && decoyValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Decoy host list not specified" )), i18n( "Decoy hosts error" ));
+	{	KMessageBox::error( this, i18n( "Decoy host list not specified" ), i18n( "Decoy hosts error" ));
 		return false;
 	}
 
 	if( excludeState && excludeValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Exclude hosts not specified" )), i18n( "Exclude hosts error" ));
+	{	KMessageBox::error( this, i18n( "Exclude hosts not specified" ), i18n( "Exclude hosts error" ));
 		return false;
 	}
 
 	if( excludeFileState && excludeFileValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Exclude hosts file name not specified" )), i18n( "Exclude hosts file name error" ));
+	{	KMessageBox::error( this, i18n( "Exclude hosts file name not specified" ), i18n( "Exclude hosts file name error" ));
 		return false;
 	}
 
 	if( interfaceState && interfaceValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Interface name not specified" )), i18n( "Interface name error" ));
+	{	KMessageBox::error( this, i18n( "Interface name not specified" ), i18n( "Interface name error" ));
 		return false;
 	}
 
 	if( sourceIPState && sourceIPValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Source IP address not specified" )), i18n( "Source IP address error" ));
+	{	KMessageBox::error( this, i18n( "Source IP address not specified" ), i18n( "Source IP address error" ));
 		return false;
 	}
 
 	if( spoofMacState && spoofMacValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Spoof MAC address not specified" )), i18n( "Spoof MAC address error" ));
+	{	KMessageBox::error( this, i18n( "Spoof MAC address not specified" ), i18n( "Spoof MAC address error" ));
 		return false;
 	}
 
 	if( targetFileState && targetFileValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Target hosts file name not specified" )), i18n( "Target hosts file name error" ));
+	{	KMessageBox::error( this, i18n( "Target hosts file name not specified" ), i18n( "Target hosts file name error" ));
 		return false;
 	}
 
@@ -680,3 +680,5 @@ void CompoundWidget::slotWhatsThisClicked( )
 	else if( m_ttlSpinBox->hasMouse( ))            emit( displayHelp( "--ttl"         ));
 	else emit( displayUnknown( ));
 }
+
+#include "compoundwidget.moc"
