@@ -184,37 +184,37 @@ bool LoggingOptions::getOptions( )
 	TQString xmlLogValue         = m_xmlLogLineEdit->text( );
 
 	if( baseFileNameState && baseFileNameValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Base file name not specified" )), i18n( "Base file name error" ));
+	{	KMessageBox::error( this, i18n( "Base file name not specified" ), i18n( "Base file name error" ));
 		return false;
 	}
 
 	if( grepableLogState && grepableLogValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "grep'able log file name not specified" )), i18n( "grep'able log file name error" ));
+	{	KMessageBox::error( this, i18n( "grep'able log file name not specified" ), i18n( "grep'able log file name error" ));
 		return false;
 	}
 
 	if( normalLogState && normalLogValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Normal log file name not specified" )), i18n( "Normal log file name error" ));
+	{	KMessageBox::error( this, i18n( "Normal log file name not specified" ), i18n( "Normal log file name error" ));
 		return false;
 	}
 
 	if( resumeState && scriptKiddieValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Resume file name not specified" )), i18n( "Resume file name error" ));
+	{	KMessageBox::error( this, i18n( "Resume file name not specified" ), i18n( "Resume file name error" ));
 		return false;
 	}
 
 	if( scriptKiddieState && scriptKiddieValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Script kiddie log file name not specified" )), i18n( "Script kiddie log file name error" ));
+	{	KMessageBox::error( this, i18n( "Script kiddie log file name not specified" ), i18n( "Script kiddie log file name error" ));
 		return false;
 	}
 
 	if( stylesheetState && stylesheetValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "XSL stylesheet file name not specified" )), i18n( "XSL stylesheet file name error" ));
+	{	KMessageBox::error( this, i18n( "XSL stylesheet file name not specified" ), i18n( "XSL stylesheet file name error" ));
 		return false;
 	}
 
 	if( xmlLogState && xmlLogValue.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "XML log file name not specified" )), i18n( "XML log file name error" ));
+	{	KMessageBox::error( this, i18n( "XML log file name not specified" ), i18n( "XML log file name error" ));
 		return false;
 	}
 
@@ -458,3 +458,5 @@ void LoggingOptions::slotXMLLogCheckBoxClicked( )
 {	m_xmlLogButton->setEnabled( m_xmlLogCheckBox->isChecked( ));
 	m_xmlLogLineEdit->setEnabled( m_xmlLogCheckBox->isChecked( ));
 }
+
+#include "loggingoptions.moc"
